NEDNSProxyProvider

Struct NEDNSProxyProvider 

pub struct NEDNSProxyProvider { /* private fields */ }
The NEDNSProxyProvider class declares the programmatic interface for an object that implements the client side of a custom DNS proxy solution.

NEDNSProxyProvider is part of NetworkExtension.framework

See also Apple’s documentation

Implementations

Source

impl NEDNSProxyProvider

pub unsafe fn startProxyWithOptions_completionHandler( &self, options: Option<&NSDictionary<NSString, AnyObject>>, completion_handler: &DynBlock<dyn Fn(*mut NSError)>, )

Available on crate feature block2 only.

This function is called by the framework when a new proxy instance is being created. Subclasses must override this method to perform whatever steps are necessary to ready the proxy for handling flows of network data.

Parameter options: A dictionary containing keys and values passed by the provider’s containing app. If the containing app did not start the proxy then this parameter will be nil.

Parameter completionHandler: A block that must be called when the process of starting the proxy is complete. If the proxy cannot be started then the subclass’ implementation of this method must pass a non-nil NSError object to this block. A value of nil passed to the completion handler indicates that the proxy was successfully started.

Safety

options generic should be of the correct type.

pub unsafe fn stopProxyWithReason_completionHandler( &self, reason: NEProviderStopReason, completion_handler: &DynBlock<dyn Fn()>, )

Available on crate feature block2 only.

This function is called by the framework when the proxy is being stopped. Subclasses must override this method to perform whatever steps are necessary to stop the proxy.

Parameter reason: An NEProviderStopReason indicating why the proxy is being stopped.

Parameter completionHandler: A block that must be called when the proxy is completely stopped.

pub unsafe fn cancelProxyWithError(&self, error: Option<&NSError>)

This function is called by proxy provider implementations to stop the proxy when a network error is encountered that renders the proxy no longer viable. Subclasses should not override this method.

Parameter error: An NSError object containing details about the error that the proxy provider implementation encountered.

pub unsafe fn handleNewFlow(&self, flow: &NEAppProxyFlow) -> bool

This function is called by the framework to deliver a new network data flow to the proxy provider implementation. Subclasses must override this method to perform whatever steps are necessary to ready the proxy to receive data from the flow. The proxy provider implementation indicates that the proxy is ready to handle flow data by calling -[NEAppProxyFlow openWithLocalFlowEndpoint:completionHandler:] on the flow. If the proxy implementation decides to not handle the flow and instead terminate it, the subclass implementation of this method should return NO. If the proxy implementation decides to handle the flow, the subclass implementation of this method should return YES. In this case the proxy implementation is responsible for retaining the NEAppProxyFlow object.

Parameter flow: The new flow

Returns: YES if the proxy implementation has retained the flow and intends to handle the flow data. NO if the proxy implementation has not retained the flow and will not handle the flow data. In this case the flow is terminated.

pub unsafe fn handleNewUDPFlow_initialRemoteEndpoint( &self, flow: &NEAppProxyUDPFlow, remote_endpoint: &NWEndpoint, ) -> bool

👎Deprecated

This function is called by the framework to deliver a new UDP data flow to the proxy provider implementation. Subclasses can override this method to perform whatever steps are necessary to ready the proxy to receive data from the flow. The proxy provider implementation indicates that the proxy is ready to handle flow data by calling -[NEAppProxyFlow openWithLocalEndpoint:completionHandler:] on the flow. If the proxy implementation decides to not handle the flow and instead terminate it, the subclass implementation of this method should return NO. If the proxy implementation decides to handle the flow, the subclass implementation of this method should return YES. In this case the proxy implementation is responsible for retaining the NEAppProxyUDPFlow object. The default implementation of this method calls -[NEAppProxyProvider handleNewFlow:] and returns its result.

Parameter flow: The new UDP flow

Parameter remoteEndpoint: The initial remote endpoint provided by the proxied app when the flow was opened.

Returns: YES if the proxy implementation has retained the flow and intends to handle the flow data. NO if the proxy implementation has not retained the flow and will not handle the flow data. In this case the flow is terminated.

pub unsafe fn systemDNSSettings( &self, ) -> Option<Retained<NSArray<NEDNSSettings>>>

The current system DNS settings. Use KVO to watch for changes.

Source

impl NEDNSProxyProvider

Methods declared on superclass NSObject.

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

pub unsafe fn new() -> Retained<Self>

Methods from Deref<Target = NEProvider>

pub unsafe fn sleepWithCompletionHandler( &self, completion_handler: &DynBlock<dyn Fn()>, )

Available on crate feature block2 only.

This function is called by the framework when the system is about to go to sleep. Subclass developers can override this method to implement custom behavior such as closing connections or pausing some network activity.

Parameter completionHandler: When the method is finished handling the sleep event it must execute this completion handler.

pub unsafe fn wake(&self)

This function is called by the framework immediately after the system wakes up from sleep. Subclass developers can override this method to implement custom behavior such as re-establishing connections or resuming some network activity.

pub unsafe fn createTCPConnectionToEndpoint_enableTLS_TLSParameters_delegate( &self, remote_endpoint: &NWEndpoint, enable_tls: bool, tls_parameters: Option<&NWTLSParameters>, delegate: Option<&AnyObject>, ) -> Retained<NWTCPConnection>

👎Deprecated:

Use nw_connection_t in Network framework instead

This function can be called by subclass implementations to create a TCP connection to a given network endpoint. This function should not be overridden by subclasses.

Parameter remoteEndpoint: An NWEndpoint object that specifies the remote network endpoint to connect to.

Parameter enableTLS: A flag indicating if a TLS session should be negotiated on the connection.

Parameter TLSParameters: A set of optional TLS parameters. Only valid if enableTLS is YES. If TLSParameters is nil, the default system parameters will be used for TLS negotiation.

Parameter delegate: An object to use as the connections delegate. This object should conform to the NWTCPConnectionAuthenticationDelegate protocol.

Returns: An NWTCPConnection object.

Safety

delegate should be of the correct type.

pub unsafe fn createUDPSessionToEndpoint_fromEndpoint( &self, remote_endpoint: &NWEndpoint, local_endpoint: Option<&NWHostEndpoint>, ) -> Retained<NWUDPSession>

👎Deprecated:

Use nw_connection_t in Network framework instead

This function can be called by subclass implementations to create a UDP session between a local network endpoint and a remote network endpoint. This function should not be overridden by subclasses.

Parameter remoteEndpoint: An NWEndpoint object that specifies the remote endpoint to which UDP datagrams will be sent by the UDP session.

Parameter localEndpoint: An NWHostEndpoint object that specifies the local IP address endpoint to use as the source endpoint of the UDP session.

Returns: An NWUDPSession object.

pub unsafe fn displayMessage_completionHandler( &self, message: &NSString, completion_handler: &DynBlock<dyn Fn(Bool)>, )

👎Deprecated
Available on crate feature block2 only.

This method can be called by subclass implementations to display a message to the user.

Parameter message: The message to be displayed.

Parameter completionHandler: A block that is executed when the user acknowledges the message. If this method is called on a NEFilterDataProvider instance or the message cannot be displayed, then the completion handler block will be executed immediately with success parameter set to NO. If the message was successfully displayed to the user, then the completion handler block is executed with the success parameter set to YES when the user dismisses the message.

pub unsafe fn defaultPath(&self) -> Option<Retained<NWPath>>

👎Deprecated:

Use nw_path_monitor_t in Network framework instead

The current default path for connections created by the provider. Use KVO to watch for network changes.

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated:

this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}