#[repr(transparent)]pub struct NEHotspotHelperResult(pub NSInteger);Expand description
The result of processing the NEHotspotHelperCommand.
The HotspotHelper provides the result of processing the NEHotspotHelperCommand when it instantiates its NEHotspotHelperResponse.
interaction. This result is only valid in response to a command with type kNEHotspotHelperCommandTypeAuthenticate.
recognize the command type.
authentication again. This result is only valid in response to a command with type kNEHotspotHelperCommandTypeMaintain.
authenticate, the helper determined that it can’t perform the authentication. This result is only valid in response to commands of type kNEHotspotHelperCommandTypeAuthenticate and kNEHotspotHelperCommandTypePresentUI.
it is temporarily unable to perform the authentication. This result is only valid in response to commands of type kNEHotspotHelperCommandTypeAuthenticate and kNEHotspotHelperCommandTypePresentUI.
See also Apple’s documentation
Tuple Fields
0: NSIntegerImplementations
Sourceimpl NEHotspotHelperResult
impl NEHotspotHelperResult
pub const Success: Self
pub const Failure: Self
pub const UIRequired: Self
pub const CommandNotRecognized: Self
pub const AuthenticationRequired: Self
pub const UnsupportedNetwork: Self
pub const TemporaryFailure: Self