pub struct NWHostEndpoint { /* private fields */ }Use nw_endpoint_t in Network framework instead, see deprecation notice in <NetworkExtension/NWHostEndpoint.h>
NWHostEndpoint is a subclass of NWEndpoint. It represents an endpoint backed by a hostname and port. Note that a hostname string may be an IP or IPv6 address.
See also Appleโs documentation
Implementations
Sourceimpl NWHostEndpoint
impl NWHostEndpoint
Sourcepub unsafe fn endpointWithHostname_port(
hostname: &NSString,
port: &NSString,
) -> Retained<Self>
๐Deprecated: Use nw_endpoint_create_host in Network framework instead, see deprecation notice in <NetworkExtension/NWHostEndpoint.h>
pub unsafe fn endpointWithHostname_port( hostname: &NSString, port: &NSString, ) -> Retained<Self>
Use nw_endpoint_create_host in Network framework instead, see deprecation notice in <NetworkExtension/NWHostEndpoint.h>
Parameter hostname: A string representation of the hostname or address, such as www.apple.com or 10.0.0.1.
Parameter port: A string containing the port on the host, such as 80.
Returns: An initialized NWHostEndpoint object.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesnโt recognize.
See Appleโs documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
๐Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
this is difficult to use correctly, use Ivar::load instead.
Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable โunder the hoodโ.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Appleโs documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called โlightweight genericsโ, and thatโs because they arenโt exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you donโt need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for NWHostEndpoint
impl AsRef<AnyObject> for NWHostEndpoint
Sourceimpl AsRef<NSObject> for NWHostEndpoint
impl AsRef<NSObject> for NWHostEndpoint
Sourceimpl AsRef<NWEndpoint> for NWHostEndpoint
impl AsRef<NWEndpoint> for NWHostEndpoint
Sourcefn as_ref(&self) -> &NWEndpoint
fn as_ref(&self) -> &NWEndpoint
Sourceimpl AsRef<NWHostEndpoint> for NWHostEndpoint
impl AsRef<NWHostEndpoint> for NWHostEndpoint
Sourceimpl Borrow<AnyObject> for NWHostEndpoint
impl Borrow<AnyObject> for NWHostEndpoint
Sourceimpl Borrow<NSObject> for NWHostEndpoint
impl Borrow<NSObject> for NWHostEndpoint
Sourceimpl Borrow<NWEndpoint> for NWHostEndpoint
impl Borrow<NWEndpoint> for NWHostEndpoint
Sourcefn borrow(&self) -> &NWEndpoint
fn borrow(&self) -> &NWEndpoint
Sourceimpl ClassType for NWHostEndpoint
impl ClassType for NWHostEndpoint
Sourceconst NAME: &'static str = "NWHostEndpoint"
const NAME: &'static str = "NWHostEndpoint"
Sourcetype Super = NWEndpoint
type Super = NWEndpoint
Sourcetype ThreadKind = <<NWHostEndpoint as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<NWHostEndpoint as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl CopyingHelper for NWHostEndpoint
impl CopyingHelper for NWHostEndpoint
Sourcetype Result = NWHostEndpoint
type Result = NWHostEndpoint
Self if the type has no
immutable counterpart. Read moreSourceimpl Debug for NWHostEndpoint
impl Debug for NWHostEndpoint
Sourceimpl Deref for NWHostEndpoint
impl Deref for NWHostEndpoint
Sourceimpl Hash for NWHostEndpoint
impl Hash for NWHostEndpoint
Sourceimpl Message for NWHostEndpoint
impl Message for NWHostEndpoint
Sourceimpl NSCopying for NWHostEndpoint
impl NSCopying for NWHostEndpoint
Sourceimpl NSObjectProtocol for NWHostEndpoint
impl NSObjectProtocol for NWHostEndpoint
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
use isKindOfClass directly, or cast your objects with AnyObject::downcast_ref