#[repr(transparent)]pub struct NWTCPConnectionState(pub NSInteger);Use nw_connection_state_t in Network framework instead, see deprecation notice in <NetworkExtension/NWTCPConnection.h>
Defined connection states. New types may be defined in the future.
See also Apple’s documentation
Tuple Fields
0: NSIntegerUse nw_connection_state_t in Network framework instead, see deprecation notice in <NetworkExtension/NWTCPConnection.h>
Implementations
Sourceimpl NWTCPConnectionState
impl NWTCPConnectionState
pub const Invalid: Self
Use nw_connection_state_t in Network framework instead, see deprecation notice in <NetworkExtension/NWTCPConnection.h>
pub const Connecting: Self
Use nw_connection_state_t in Network framework instead, see deprecation notice in <NetworkExtension/NWTCPConnection.h>
Sourcepub const Waiting: Self
👎Deprecated: Use nw_connection_state_t in Network framework instead, see deprecation notice in <NetworkExtension/NWTCPConnection.h>
pub const Waiting: Self
Use nw_connection_state_t in Network framework instead, see deprecation notice in <NetworkExtension/NWTCPConnection.h>
waiting for better condition(s) before trying again.
Sourcepub const Connected: Self
👎Deprecated: Use nw_connection_state_t in Network framework instead, see deprecation notice in <NetworkExtension/NWTCPConnection.h>
pub const Connected: Self
Use nw_connection_state_t in Network framework instead, see deprecation notice in <NetworkExtension/NWTCPConnection.h>
to transfer data. If TLS is in use, the TLS handshake would have finished when the connection is in this state.
Sourcepub const Disconnected: Self
👎Deprecated: Use nw_connection_state_t in Network framework instead, see deprecation notice in <NetworkExtension/NWTCPConnection.h>
pub const Disconnected: Self
Use nw_connection_state_t in Network framework instead, see deprecation notice in <NetworkExtension/NWTCPConnection.h>
possible to transfer data. The application should call cancellation method to clean up resources when the connection is in this state.