#[repr(transparent)]pub struct NWUDPSessionState(pub NSInteger);Use nw_connection_state_t in Network framework instead, see deprecation notice in <NetworkExtension/NWUDPSession.h>
UDP session state values
See also Apple’s documentation
Tuple Fields
0: NSIntegerUse nw_connection_state_t in Network framework instead, see deprecation notice in <NetworkExtension/NWUDPSession.h>
Implementations
Sourceimpl NWUDPSessionState
impl NWUDPSessionState
pub const Invalid: Self
Use nw_connection_state_t in Network framework instead, see deprecation notice in <NetworkExtension/NWUDPSession.h>
Sourcepub const Waiting: Self
👎Deprecated: Use nw_connection_state_t in Network framework instead, see deprecation notice in <NetworkExtension/NWUDPSession.h>
pub const Waiting: Self
Use nw_connection_state_t in Network framework instead, see deprecation notice in <NetworkExtension/NWUDPSession.h>
attempting to make the session ready.
pub const Preparing: Self
Use nw_connection_state_t in Network framework instead, see deprecation notice in <NetworkExtension/NWUDPSession.h>
pub const Ready: Self
Use nw_connection_state_t in Network framework instead, see deprecation notice in <NetworkExtension/NWUDPSession.h>
Sourcepub const Failed: Self
👎Deprecated: Use nw_connection_state_t in Network framework instead, see deprecation notice in <NetworkExtension/NWUDPSession.h>
pub const Failed: Self
Use nw_connection_state_t in Network framework instead, see deprecation notice in <NetworkExtension/NWUDPSession.h>
at this time, either due to problems with the path or the client rejecting the endpoints.
pub const Cancelled: Self
Use nw_connection_state_t in Network framework instead, see deprecation notice in <NetworkExtension/NWUDPSession.h>