NEAppPushDelegate

Trait NEAppPushDelegate 

pub unsafe trait NEAppPushDelegate: NSObjectProtocol {
    // Provided method
    unsafe fn appPushManager_didReceiveIncomingCallWithUserInfo(
        &self,
        manager: &NEAppPushManager,
        user_info: &NSDictionary,
    )
       where Self: Sized + Message { ... }
}
Delegate for NEAppPushManager.

See also Apple’s documentation

Provided Methods

unsafe fn appPushManager_didReceiveIncomingCallWithUserInfo( &self, manager: &NEAppPushManager, user_info: &NSDictionary, )
where Self: Sized + Message,

This delegate method is called when the provider reports incoming call using reportIncomingCommunicationWithUserInfo method.

Parameter userInfo: A dictionary of custom information that the provider passes to reportIncomingCommunicationWithUserInfo method.

Safety

user_info generic should be of the correct type.